Welcome to guniflask |version|
==============================

Overview
--------

guniflask是自动化生成基于flask + gunicorn的服务端项目基础代码的构建工具。

Installation
------------

guniflask需要Python 3.6或更高版本的环境支持。

可以通过pip安装或升级guniflask::

    $ pip install -U guniflask


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    run

.. toctree::
    :maxdepth: 2

    config
    settings
    app
    blueprints
    orm
    log
    debug
    deploy

.. toctree::
    :maxdepth: 1

    changelog
